<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">

<!--
SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.

SPDX-License-Identifier: LGPL-3.0-or-later
-->

<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="190"/>
        <source>Acknowledgements</source>
        <translation>Выражение признательности</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1528"/>
        <source>Version: %1</source>
        <translation>Версия: %1</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1532"/>
        <source>%1 is released under %2</source>
        <translation>%1 выпущен под %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="840"/>
        <source>Black</source>
        <translation>Черный</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="843"/>
        <source>White</source>
        <translation>Белый</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="846"/>
        <source>Dark Gray</source>
        <translation>Темно-Серый</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="849"/>
        <source>Gray</source>
        <translation>Серый</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="852"/>
        <source>Light Gray</source>
        <translation>Светло-Серый</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="855"/>
        <source>Red</source>
        <translation>Красный</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="858"/>
        <source>Green</source>
        <translation>Зеленый</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="861"/>
        <source>Blue</source>
        <translation>Синий</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="864"/>
        <source>Cyan</source>
        <translation>Голубой</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="867"/>
        <source>Magenta</source>
        <translation>Пурпурный</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="870"/>
        <source>Yellow</source>
        <translation>Желтый</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="873"/>
        <source>Dark Red</source>
        <translation>Темно-Красный</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="876"/>
        <source>Dark Green</source>
        <translation>Темно-Зеленый</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="879"/>
        <source>Dark Blue</source>
        <translation>Темно-Синий</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="882"/>
        <source>Dark Cyan</source>
        <translation>Темно-Голубой</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="885"/>
        <source>Dark Magenta</source>
        <translation>Темно-Пурпурный</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="888"/>
        <source>Dark Yellow</source>
        <translation>Темно-Желтый</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="86"/>
        <source>Enter a new shortcut</source>
        <translation>Введите новое сочетание клавиш</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="562"/>
        <source>Stop reading</source>
        <translation>Прекращение чтения</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="564"/>
        <source>Text to Speech</source>
        <translation>Преобразование текста в речь</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="587"/>
        <source>Translate</source>
        <translation>Перевод</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="609"/>
        <source>Speech To Text</source>
        <translation>Преобразование речи в текст</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="235"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1181"/>
        <source>Advanced</source>
        <translation>Продвинутый</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="258"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="259"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1597"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>Печать</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="275"/>
        <source>Basic</source>
        <translation>Основной</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="290"/>
        <source>Printer</source>
        <translation>Принтер</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="304"/>
        <source>Copies</source>
        <translation>Копии</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
        <source>Page range</source>
        <translation>Диапазон страницы</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="326"/>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="327"/>
        <source>Current page</source>
        <translation>Текущая страница</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="328"/>
        <source>Select pages</source>
        <translation>Выбрать страницы</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="343"/>
        <source>Orientation</source>
        <translation>Ориентация</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="367"/>
        <source>Portrait</source>
        <translation>Портрет</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="377"/>
        <source>Landscape</source>
        <translation>Ландшафт</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="405"/>
        <source>Pages</source>
        <translation>Страницы</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="415"/>
        <source>Color mode</source>
        <translation>Цветовой режим</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="417"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1554"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1621"/>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="417"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1606"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1621"/>
        <source>Grayscale</source>
        <translation>Градация серого</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="428"/>
        <source>Margins</source>
        <translation>Поля</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Narrow (mm)</source>
        <translation>Узкий (мм)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Normal (mm)</source>
        <translation>Обычный (мм)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Moderate (mm)</source>
        <translation>Умеренный (мм)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Customize (mm)</source>
        <translation>Настроить (мм)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
        <source>Top</source>
        <translation>Верх</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
        <source>Left</source>
        <translation>Лево</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
        <source>Bottom</source>
        <translation>Низ</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="445"/>
        <source>Right</source>
        <translation>Право</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="490"/>
        <source>Scaling</source>
        <translation>Масштабирование</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="504"/>
        <source>Actual size</source>
        <translation>Текущий размер</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="513"/>
        <source>Scale</source>
        <translation>Масштаб</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="544"/>
        <source>Paper</source>
        <translation>Бумага</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="554"/>
        <source>Paper size</source>
        <translation>Размер бумаги</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="567"/>
        <source>Print Layout</source>
        <translation>Макет Печати</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="578"/>
        <source>Duplex</source>
        <translation>Двойной</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="591"/>
        <source>N-up printing</source>
        <translation>Печать N-страниц</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 страницы/лист, 1х2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 страниц/лист, 2х2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 страниц/лист, 2х3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 страниц/лист, 3х3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 страниц/лист, 4х4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="602"/>
        <source>Layout direction</source>
        <translation>Направление макета</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="647"/>
        <source>Page Order</source>
        <translation>Порядок страниц</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="658"/>
        <source>Collate pages</source>
        <translation>Сопоставление страниц</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="664"/>
        <source>Print pages in order</source>
        <translation>Печать страниц согласно порядку</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="666"/>
        <source>Front to back</source>
        <translation>С лицевой стороны обратно</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="666"/>
        <source>Back to front</source>
        <translation> С обратной стороны на лицевую</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="690"/>
        <source>Watermark</source>
        <translation>Водяной знак</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="701"/>
        <source>Add watermark</source>
        <translation>Добавить водяной знак</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="743"/>
        <source>Text watermark</source>
        <translation>Водяной знак на тексте</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Confidential</source>
        <translation>Конфиденциально</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Draft</source>
        <translation>Черновик</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Sample</source>
        <translation>Пример</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Custom</source>
        <translation>Настройка</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="753"/>
        <source>Input your text</source>
        <translation>Введите текст</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="776"/>
        <source>Picture watermark</source>
        <translation>Изображение водяного знака</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="797"/>
        <source>Layout</source>
        <translation>Макет</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="799"/>
        <source>Tile</source>
        <translation>Покрыть</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="799"/>
        <source>Center</source>
        <translation>Центр</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="810"/>
        <source>Angle</source>
        <translation>Угол</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="826"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="847"/>
        <source>Transparency</source>
        <translation>Прозрачность</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="904"/>
        <source>Print to PDF</source>
        <translation>Печать в PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="905"/>
        <source>Save as Image</source>
        <translation>Сохранить как изображение</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1177"/>
        <source>Collapse</source>
        <translation>Свернуть</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1307"/>
        <source>Flip on short edge</source>
        <translation>Отразить по короткому краю</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1303"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1306"/>
        <source>Flip on long edge</source>
        <translation>Отразить по длинному краю</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1397"/>
        <source>Input page numbers please</source>
        <translation>Пожалуйста, введите номера страниц</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1400"/>
        <source>Maximum page number reached</source>
        <translation>Достигнуто максимальное количество страниц</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1403"/>
        <source>Input English comma please</source>
        <translation>Пожалуйста, введите английскую запятую</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1406"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>Введите номера страниц следующим образом: 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1559"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2174"/>
        <source>*.pdf</source>
        <translation>*.pdf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1673"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>Например, 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2174"/>
        <source>Save as PDF</source>
        <translation>Сохранить в PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2213"/>
        <source>Save as image</source>
        <translation>Сохранить как изображение</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2215"/>
        <source>Images</source>
        <translation>Изображения</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1619"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1622"/>
        <source>Confidential</source>
        <translation>Конфиденциально</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1637"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1640"/>
        <source>Draft</source>
        <translation>Черновик</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1655"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1658"/>
        <source>Sample</source>
        <translation>Пример</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="297"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="78"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="79"/>
        <source>Replace</source>
        <translation>Заменить</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="81"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>Выбранное сочетание клавиш конфликтует с %1, нажмите Добавить, чтобы  применить данное сочетание</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Пожалуйста введите новое сочетание</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>Ничего</translation>
    </message>
</context>
<context>
    <name>DSplitScreenWidget</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="215"/>
        <source>Unmaximize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="218"/>
        <source>Maximize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="258"/>
        <source>Tile window to left of screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="259"/>
        <source>Tile window to right of screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="185"/>
        <source>Stop reading</source>
        <translation>Прекращение чтения</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="187"/>
        <source>Text to Speech</source>
        <translation>Преобразование текста в речь</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="210"/>
        <source>Translate</source>
        <translation>Перевод</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="232"/>
        <source>Speech To Text</source>
        <translation>Преобразование речи в текст</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="110"/>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="536"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="539"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="545"/>
        <source>Select All</source>
        <translation>Выбрать все</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1366"/>
        <source>No search result</source>
        <translation>Поиск не дал результатов</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="340"/>
        <source>Restore Defaults</source>
        <translation>Восстановить значения По-умолчанию</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="177"/>
        <source>Select All</source>
        <translation>Выбрать все</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="117"/>
        <source>Please enter a new shortcut</source>
        <translation>Пожалуйста введите новое сочетание</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="770"/>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="772"/>
        <source>Light Theme</source>
        <translation>Светлая Тема</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="773"/>
        <source>Dark Theme</source>
        <translation>Темная Тема</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="774"/>
        <source>System Theme</source>
        <translation>Тема Системы</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="799"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="807"/>
        <source>Feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="814"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="821"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
</context>
</TS>